package com.pointrlabs.sample.splash

import androidx.appcompat.app.AppCompatActivity
import com.pointrlabs.core.management.interfaces.PointrListener
import android.widget.TextView
import android.os.Bundle
import com.pointrlabs.sample.R
import com.pointrlabs.core.management.Pointr
import com.pointrlabs.core.nativecore.wrappers.Plog
import android.widget.Toast
import com.pointrlabs.core.BuildConfig
import com.pointrlabs.sample.selection.SelectionActivity

/**
 * Activity to show loading spinner until [Pointr] is ready.
 * This is the launcher activity for the sample
 */
class PointrLoadingActivity : AppCompatActivity(), PointrListener {
    private var progressSpinner: PointrProgressSpinner? = null
    private var textViewStatus: TextView? = null
    public override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_splash)
        progressSpinner = findViewById(R.id.progressSpinner)
        textViewStatus = findViewById(R.id.textViewStatus)
        val pointr = Pointr.getPointr()!!
        pointr.start()
        pointr.addListener(this)
        Plog.i("Pointr SDK version: " + BuildConfig.VERSION_NAME)
        textViewStatus?.text = pointr.state.toString()
        if (pointr.state == Pointr.State.RUNNING) {
            startSelectionActivity()
        }
    }

    public override fun onStart() {
        super.onStart()
        progressSpinner!!.show()
    }

    public override fun onStop() {
        super.onStop()
        progressSpinner!!.hide()
    }

    public override fun onDestroy() {
        super.onDestroy()
        assert(Pointr.getPointr() != null)
        Pointr.getPointr()!!.removeListener(this)
    }

    override fun onStateUpdated(state: Pointr.State) {
        runOnUiThread {
            textViewStatus!!.text = state.toString()
            Toast.makeText(this, state.toString(), Toast.LENGTH_SHORT).show()
        }
        if (state == Pointr.State.RUNNING) {
            startSelectionActivity()
        }
    }

    private fun startSelectionActivity() {
        runOnUiThread {
            startActivity(SelectionActivity.newIntent(this))
            finish()
        }
    }
}